==> cinepaint-0.21-1.tar.gz: cinepaint-0.21-1/plug-ins/bracketing_to_hdr/gui/ImageTable.hpp <==
/*
 * gui/ImageTable.hpp  --  Part of the CinePaint plug-in "Bracketing_to_HDR"
 *
 * Copyright (c) 2005-2006  Hartmut Sbosny  <hartmut.sbosny@gmx.de>
 *
 * LICENSE:
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
/**
  ImageTable.hpp
*/
#ifndef ImageTable_hpp
#define ImageTable_hpp

#include <FL/Fl_Float_Input.H>
#include "../FL_adds/Fl_Table.H"
#include "../core/Br2Hdr.hpp"           // Br2Hdr
#include "../core/EventReceiver.hpp"    // EventReceiver      
#include "../core/br_macros.hpp"        // DTOR()


//  Using an input widget in Fl_Table accordingly to Ercolano's 
//   "singleinput.cxx" example. Un/define it for testing.
#define BR_TIME_INPUT


/**================================================================
* 
*   @class  ImageTable
* 
*   Tabelle praesentiert Bildmetadaten des ImgVectors des globalen, singlaeren
*    Manager-Objektes Br2Hdr::Instance(). 
* 
*   Ctor besitzt ausdruecklich nur die Widget-Argumentliste, um in Fluid
*    positionierbar zu sein. Dadurch leider keine Referenz des Datenobjekts
*    ('Br2HdrManager') im Ctor mitteilbar (lokale Variante). Stattdessen wird
*    hier intern auf das globale Objekt Br2Hdr::Instance() Bezug genommen. 
*
*   Im Ctor wird Zeilenzahl der Tabelle gesetzt, gewoehnlich 0 (zum Programm-
*    start). (Nach)Laden von Bildern erfordert stets Zeilenzahl anzupassen!
*  
*====================================================================*/
class ImageTable : public Fl_Table, public br::EventReceiver
{
    br::Br2Hdr &     m_Br2Hdr;       // synonym for "Br2Hdr::Instance()"
    
#ifdef BR_TIME_INPUT    
    Fl_Float_Input*  input_;         // for input of exposure times
    int              row_edit_;
    const static int col_edit_ = 4;  // column of exposure time 
#endif    

protected:
    void draw_cell (TableContext context,   // table cell drawing
                    int R=0, int C=0, int X=0, int Y=0, int W=0, int H=0);

public:
    ImageTable (int X, int Y, int W, int H, const char *la=0); 
    ~ImageTable()    {DTOR(label());}
    
    void handle_Event (br::Br2Hdr::Event);  // virtual Receiver inheritance

private:      
    void        cb_event ();
    static void cb_event_(Fl_Widget*, ImageTable* I)   
      { I -> cb_event(); }

#ifdef BR_TIME_INPUT    
    void        cb_input ();
    static void cb_input_(Fl_Widget*, ImageTable* I)   
      { I -> cb_input(); }
#endif      
};



#endif  // ImageTable_hpp
                    
// END OF FILE

==> cinepaint_0.21-2.orig.tar.gz: cinepaint-0.21-2/plug-ins/bracketing_to_hdr/gui/ImageTable.hpp <==
/*
 * ImageTable.hpp  --  Part of the CinePaint plug-in "Bracketing_to_HDR"
 *
 * Copyright (c) 2005-2006  Hartmut Sbosny  <hartmut.sbosny@gmx.de>
 *
 * LICENSE:
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
/**
  ImageTable.hpp
*/
#ifndef ImageTable_hpp
#define ImageTable_hpp


#include <FL/Fl_Float_Input.H>
#include "../FL_adds/Fl_Table.H"
#include "Br2Hdr.hpp"                   // Br2Hdr
#include "EventReceiver.hpp"            // EventReceiver      
#include "../br_core/br_macros.hpp"     // DTOR()


/*  Using an input widget in Fl_Table accordingly to Ercolano's 
     "singleinput.cxx" example. Un/define it for testing. */
#define BR_TIME_INPUT


/**===========================================================================

  @class  ImageTable

  Tabelle praesentiert Bildmetadaten des ImgVectors des globalen, singlaeren
   Manager-Objektes Br2Hdr::Instance(). 

  Ctor besitzt ausdruecklich nur die Widget-Argumentliste, um in Fluid
   positionierbar zu sein. Dadurch leider keine Referenz des Datenobjekts
   ('Br2HdrManager') im Ctor mitteilbar (lokale Variante). Stattdessen wird
   hier intern auf das globale Objekt Br2Hdr::Instance() Bezug genommen. 

  Im Ctor wird Zeilenzahl der Tabelle gesetzt, gewoehnlich 0 (zum Programm-
   start). (Nach)Laden von Bildern erfordert stets Zeilenzahl anzupassen!

*============================================================================*/
class ImageTable : public Fl_Table, public br::EventReceiver
{
    br::Br2Hdr &     m_Br2Hdr;       // synonym for "Br2Hdr::Instance()"
    
#ifdef BR_TIME_INPUT    
    Fl_Float_Input*  input_;         // for input of exposure times
    int              row_edit_;
    const static int col_edit_ = 4;  // column of exposure time 
#endif    

protected:
    void draw_cell (TableContext context,   // table cell drawing
                    int R=0, int C=0, int X=0, int Y=0, int W=0, int H=0);

public:
    ImageTable (int X, int Y, int W, int H, const char *la=0); 
    ~ImageTable()    {DTOR(label());}
    
    void handle_Event (br::Br2Hdr::Event);  // virtual Receiver inheritance

private:      
    void        cb_event ();
    static void cb_event_(Fl_Widget*, ImageTable* I)   
      { I -> cb_event(); }

#ifdef BR_TIME_INPUT    
    void        cb_input ();
    static void cb_input_(Fl_Widget*, ImageTable* I)   
      { I -> cb_input(); }
#endif      
};


#endif  // ImageTable_hpp

// END OF FILE
